"""djangoldp_notifications URL Configuration"""
from django.conf.urls import url
from .models import Notification
from djangoldp.views import LDPViewSet


urlpatterns = [
    url(r'^notifications/', LDPViewSet.urls(model=Notification)),
]



import factory
from .models import Notification
from django.contrib.auth.models import User
from django.db.models.signals import post_save

@factory.django.mute_signals(post_save)
class NotificationFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = Notification

    type = factory.Faker('text', max_nb_chars=50)
    summary = factory.Faker('paragraph', nb_sentences=3, variable_nb_sentences=True)
    author_user = factory.Iterator(User.objects.all())
    user = factory.Iterator(User.objects.all())
    date = factory.Faker('past_datetime')
    read = factory.Faker('boolean')
    object = factory.Faker('url')


from django.db import models
from django.conf import settings
from django.contrib.auth.models import User

class Notification(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='notifications_received')
    author_user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='notifications_sent')
    object = models.URLField()
    type = models.CharField(max_length=255)
    summary = models.TextField()
    date = models.DateTimeField(auto_now_add=True)
    read = models.BooleanField()
    class Meta:
        rdf_type = 'sib:source'
        permissions = (
            ('view_notification', 'Read'),
            ('control_notification', 'Control'),
        )
        auto_author = 'author_user'
        ordering = ['date']

    def __str__(self):
        return '{}'.format(self.type)
